@@ -435,6 +435,12 @@ void WindowSystem::setType(WId win, NET::WindowType windowType)
     case NET::OnScreenDisplay:
         role = KWayland::Client::PlasmaShellSurface::Role::OnScreenDisplay;
         break;
+    case NET::Notification:
+        role = KWayland::Client::PlasmaShellSurface::Role::Notification;
+        break;
+    case NET::Tooltip:
+        role = KWayland::Client::PlasmaShellSurface::Role::ToolTip;
+        break;
     default:
         return;
     }
